--- old/usr/src/uts/common/vm/pvn.h	2015-01-10 07:32:26.992964088 -0500
+++ new/usr/src/uts/common/vm/pvn.h	2015-01-10 07:32:26.999981867 -0500
@@ -91,27 +91,6 @@
  */
 #define	PVN_VPLIST_HASH_TAG	((page_t *)-1)
 
-/*
- * When requesting pages from the getpage routines, pvn_getpages will
- * allocate space to return PVN_GETPAGE_NUM pages which map PVN_GETPAGE_SZ
- * worth of bytes.  These numbers are chosen to be the minimum of the max's
- * given in terms of bytes and pages.
- */
-#define	PVN_MAX_GETPAGE_SZ	0x10000		/* getpage size limit */
-#define	PVN_MAX_GETPAGE_NUM	0x8		/* getpage page limit */
-
-#if PVN_MAX_GETPAGE_SZ > PVN_MAX_GETPAGE_NUM * PAGESIZE
-
-#define	PVN_GETPAGE_SZ	ptob(PVN_MAX_GETPAGE_NUM)
-#define	PVN_GETPAGE_NUM	PVN_MAX_GETPAGE_NUM
-
-#else
-
-#define	PVN_GETPAGE_SZ	PVN_MAX_GETPAGE_SZ
-#define	PVN_GETPAGE_NUM	btop(PVN_MAX_GETPAGE_SZ)
-
-#endif
-
 #endif	/* _KERNEL */
 
 #ifdef	__cplusplus
--- old/usr/src/uts/common/vm/seg_vn.c	2015-01-10 07:32:27.197632360 -0500
+++ new/usr/src/uts/common/vm/seg_vn.c	2015-01-10 07:32:27.205663002 -0500
@@ -20,6 +20,7 @@
  */
 /*
  * Copyright (c) 1986, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright 2015 Nexenta Systems, Inc.  All rights reserved.
  */
 
 /*	Copyright (c) 1984, 1986, 1987, 1988, 1989 AT&T	*/
@@ -73,6 +74,27 @@
 #include <sys/project.h>
 #include <sys/zone.h>
 #include <sys/shm_impl.h>
+
+/*
+ * segvn_fault needs a temporary page list array.  To avoid calling kmem all
+ * the time, it creates a small (PVN_GETPAGE_NUM entry) array and uses it if
+ * it can.  In the rare case when this page list is not large enough, it
+ * goes and gets a large enough array from kmem.
+ *
+ * This small page list array covers either 8 pages or 64kB worth of pages -
+ * whichever is smaller.
+ */
+#define	PVN_MAX_GETPAGE_SZ	0x10000
+#define	PVN_MAX_GETPAGE_NUM	0x8
+
+#if PVN_MAX_GETPAGE_SZ > PVN_MAX_GETPAGE_NUM * PAGESIZE
+#define	PVN_GETPAGE_SZ	ptob(PVN_MAX_GETPAGE_NUM)
+#define	PVN_GETPAGE_NUM	PVN_MAX_GETPAGE_NUM
+#else
+#define	PVN_GETPAGE_SZ	PVN_MAX_GETPAGE_SZ
+#define	PVN_GETPAGE_NUM	btop(PVN_MAX_GETPAGE_SZ)
+#endif
+
 /*
  * Private seg op routines.
  */
